/* objops.h
 * header file for operations to objects
 *
 * for Denemo, a gtk+ frontend to GNU Lilypond
 * (c) 1999-2005 Matthew Hiller
 */
#ifndef OBJOPS_H
#define OBJOPS_H 

#include <denemo/denemo.h>

void
freeobject (mudelaobject *mudobj);

mudelaobject *
newtimesigobj (gint time1, gint time2);

mudelaobject *
newclefobj (enum clefs type);

void
initkeyaccs (gint *accs, gint number);

mudelaobject *
newkeyobj (gint number, gint isminor, gint mode); /* default mode: 0 */

mudelaobject *
newmeasurebreakobject ();

mudelaobject *
clone_object (mudelaobject * orig);

mudelaobject *
stem_directive_new (enum stemdirections type);

mudelaobject *
lily_directive_new (gchar* type);

mudelaobject *
dynamic_new (gchar *type);

mudelaobject *
lyric_new(gchar *type, gint position, gboolean syllable);

/* create one mudelaobject of type not known to denemo otherwise 
*  no object is associated. */
mudelaobject *
newobj(enum objtype type);


void setinitialkeysig(staff *curstaff, gint tokey, gint type);
#endif
